@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: cpl_vsi.h bda7a9d474478a3c09dcd7c9c26c4a0375c79e27 2020-08-31 13:37:23 +0200 Thomas Bonfort $
+ * $Id: cpl_vsi.h 63047152a3b5ceb7293ae884fb96be39cd428383 2020-09-30 13:00:56 +0200 Thomas Bonfort $
  *
  * Project:  CPL - Common Portability Library
  * Author:   Frank Warmerdam, warmerdam@pobox.com
@@ -312,6 +312,7 @@ GIntBig CPL_DLL CPLGetUsablePhysicalRAM(void);
 char CPL_DLL **VSIReadDir( const char * );
 char CPL_DLL **VSIReadDirRecursive( const char *pszPath );
 char CPL_DLL **VSIReadDirEx( const char *pszPath, int nMaxFiles );
+char CPL_DLL **VSISiblingFiles( const char *pszPath );
 
 /** Opaque type for a directory iterator */
 typedef struct VSIDIR VSIDIR;
@@ -373,6 +374,9 @@ int CPL_DLL VSISync( const char* pszSource, const char* pszTarget,
 char CPL_DLL *VSIStrerror( int );
 GIntBig CPL_DLL VSIGetDiskFreeSpace(const char *pszDirname);
 
+void CPL_DLL VSINetworkStatsReset( void );
+char CPL_DLL *VSINetworkStatsGetAsSerializedJSON( char** papszOptions );
+
 /* ==================================================================== */
 /*      Install special file access handlers.                           */
 /* ==================================================================== */
@@ -451,6 +455,15 @@ typedef int            (*VSIFilesystemPluginRmdirCallback)         ( void *pUser
  * @since GDAL 3.0
  */
 typedef char**         (*VSIFilesystemPluginReadDirCallback)       ( void *pUserData, const char *pszDirname, int nMaxFiles );
+/** 
+ * List related files. Must return NULL if unknown, or a list of relative filenames
+ * that can be opened along the main file. If no other file than pszFilename needs to
+ * be opened, return static_cast<char**> (CPLCalloc(1,sizeof(char*)));
+ * 
+ * Optional
+ * @since GDAL 3.2
+ */
+typedef char**         (*VSIFilesystemPluginSiblingFilesCallback)       ( void *pUserData, const char *pszDirname );
 /** 
  * Open a handle. Mandatory. Returns an opaque pointer that will be used in subsequent file I/O calls.
  * Should return null and/or set errno if the handle does not exist or the access mode is incorrect.
@@ -511,7 +524,7 @@ typedef int            (*VSIFilesystemPluginCloseCallback)         ( void *pFile
 
 /**
  * struct containing callbacks to used by the handler.
- * (rw), (r), (w) or () at the end indicate wether the given callback is mandatory
+ * (rw), (r), (w) or () at the end indicate whether the given callback is mandatory
  * for reading and or writing handlers. A (?) indicates that the callback might
  * be mandatory for certain drivers only.
  * @since GDAL 3.0
@@ -540,6 +553,7 @@ typedef struct {
     VSIFilesystemPluginCloseCallback            close; /**< close handle  (rw) */
     size_t                                      nBufferSize; /**< buffer small reads (makes handler read only) */
     size_t                                      nCacheSize; /**< max mem to use per file when buffering */
+    VSIFilesystemPluginSiblingFilesCallback     sibling_files; /**< list related files*/
 /* 
     Callbacks are defined as a struct allocated by a call to VSIAllocFilesystemPluginCallbacksStruct
     in order to try to maintain ABI stability when eventually adding a new member.
